pywws.conversions — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »

# pywws.conversions

conversions.py est un ensemble de fonctions pour convertir les unités pywws natives (centigrades, mm, m / s, hPa), en d’autres unités de mesure populaires

Fonctions

`pressure_inhg`(hPa) | Converti la pression de hectopascals/millibars, à pouces de mercure
`rain_inch`(mm) | Converti les précipitations de millimètres, à pouces
`temp_f`(c) | Converti la température de Celsius, à Fahrenheit
`wind_bft`(ms) | Converti la vitesse du vent de mètres par seconde, vers l’échelle Beaufort
`wind_kmph`(ms) | Converti la vitesse du vent de mètres par seconde, à kilomètres par heure
`wind_kn`(ms) | Converti la vitesse du vent de mètres par seconde, à noeuds
`wind_mph`(ms) | Converti la vitesse du vent de mètres par seconde, en miles par heure

`pywws.conversions.` `illuminance_wm2`(lux)

  Conversion approximative de la luminosité en lux, au rayonnement solaire en W/m2

`pywws.conversions.` `pressure_inhg`(hPa)

  Converti la pression de hectopascals/millibars, à pouces de mercure

`pywws.conversions.` `rain_inch`(mm)

  Converti les précipitations de millimètres, à pouces

`pywws.conversions.` `temp_f`(c)

  Converti la température de Celsius, à Fahrenheit

`pywws.conversions.` `winddir_degrees`(pts)

  Converti la direction du vent de 0..15 en degrés

`pywws.conversions.` `winddir_text`(pts)

  Converti la direction du vent de 0..15, en points cardinaux

`pywws.conversions.` `wind_kmph`(ms)

  Converti la vitesse du vent de mètres par seconde, à kilomètres par heure

`pywws.conversions.` `wind_mph`(ms)

  Converti la vitesse du vent de mètres par seconde, en miles par heure

`pywws.conversions.` `wind_kn`(ms)

  Converti la vitesse du vent de mètres par seconde, à noeuds

`pywws.conversions.` `wind_bft`(ms)

  Converti la vitesse du vent de mètres par seconde, vers l’échelle Beaufort

`pywws.conversions.` `cadhumidex`(temp, humidity)

  Calculate Humidity Index as per Canadian Weather Standards

`pywws.conversions.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »